==> cdktf_cdktf_provider_azurerm-0.5.60-py3-none-any.whl: package/lib/data-azurerm-function-app-host-keys.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermFunctionAppHostKeysConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app_host_keys#name DataAzurermFunctionAppHostKeys#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app_host_keys#resource_group_name DataAzurermFunctionAppHostKeys#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app_host_keys#timeouts DataAzurermFunctionAppHostKeys#timeouts}
    */
    readonly timeouts?: DataAzurermFunctionAppHostKeysTimeouts;
}
export interface DataAzurermFunctionAppHostKeysTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app_host_keys#read DataAzurermFunctionAppHostKeys#read}
    */
    readonly read?: string;
}
export declare function dataAzurermFunctionAppHostKeysTimeoutsToTerraform(struct?: DataAzurermFunctionAppHostKeysTimeoutsOutputReference | DataAzurermFunctionAppHostKeysTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermFunctionAppHostKeysTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataAzurermFunctionAppHostKeysTimeouts | undefined;
    set internalValue(value: DataAzurermFunctionAppHostKeysTimeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/function_app_host_keys azurerm_function_app_host_keys}
*/
export declare class DataAzurermFunctionAppHostKeys extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/function_app_host_keys azurerm_function_app_host_keys} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermFunctionAppHostKeysConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermFunctionAppHostKeysConfig);
    get defaultFunctionKey(): string;
    get durabletaskExtensionKey(): string;
    get eventGridExtensionConfigKey(): string;
    get id(): string;
    get masterKey(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get primaryKey(): string;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    get signalrExtensionKey(): string;
    private _timeouts;
    get timeouts(): DataAzurermFunctionAppHostKeysTimeoutsOutputReference;
    putTimeouts(value: DataAzurermFunctionAppHostKeysTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzurermFunctionAppHostKeysTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-0.6.16-py3-none-any.whl: package/lib/data-azurerm-function-app-host-keys.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermFunctionAppHostKeysConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app_host_keys#name DataAzurermFunctionAppHostKeys#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app_host_keys#resource_group_name DataAzurermFunctionAppHostKeys#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app_host_keys#timeouts DataAzurermFunctionAppHostKeys#timeouts}
    */
    readonly timeouts?: DataAzurermFunctionAppHostKeysTimeouts;
}
export interface DataAzurermFunctionAppHostKeysTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/function_app_host_keys#read DataAzurermFunctionAppHostKeys#read}
    */
    readonly read?: string;
}
export declare function dataAzurermFunctionAppHostKeysTimeoutsToTerraform(struct?: DataAzurermFunctionAppHostKeysTimeoutsOutputReference | DataAzurermFunctionAppHostKeysTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermFunctionAppHostKeysTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataAzurermFunctionAppHostKeysTimeouts | undefined;
    set internalValue(value: DataAzurermFunctionAppHostKeysTimeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/function_app_host_keys azurerm_function_app_host_keys}
*/
export declare class DataAzurermFunctionAppHostKeys extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "azurerm_function_app_host_keys";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/function_app_host_keys azurerm_function_app_host_keys} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermFunctionAppHostKeysConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermFunctionAppHostKeysConfig);
    get defaultFunctionKey(): string;
    get durabletaskExtensionKey(): string;
    get eventGridExtensionConfigKey(): string;
    get id(): string;
    get masterKey(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get primaryKey(): string;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    get signalrExtensionKey(): string;
    private _timeouts;
    get timeouts(): DataAzurermFunctionAppHostKeysTimeoutsOutputReference;
    putTimeouts(value: DataAzurermFunctionAppHostKeysTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzurermFunctionAppHostKeysTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
